==> astro-1.0.15.tgz: package/src/index.ts <==
import { join } from 'node:path';
import { fileURLToPath } from 'node:url';
import type { AstroConfig, AstroIntegration } from 'astro';
import { envField, passthroughImageService } from 'astro/config';
import chokidar from 'chokidar';
import { outdent } from 'outdent';
import type { Model } from './types.js';
import { EXTENSIONS_DIR, GIT_IGNORED_DIR } from './directories.js';
import { patchAstroInlineScripts } from './plugins/patchAstroInlineScripts.js';
import { patchGlobal } from './plugins/patchGlobal.js';
import { createProjectModel } from './utils/createProjectModel.js';
import { outputDir, writeJson } from './utils/fs-utils.js';
import { generateAppManifest } from './utils/generateAppManifest.js';
import { isValidBackofficeComponent } from './utils/isValidBackofficeComponent.js';
import { isValidServicePluginComponent } from './utils/isValidServicePluginComponent.js';
import { isValidWebhookComponent } from './utils/isValidWebhookComponent.js';
import { resolveBuildMetadata } from './utils/resolveBuildMetadata.js';
import { writeVirtualBackofficeExtensionFiles } from './utils/writeVirtualBackofficeExtensionFiles.js';
import { writeVirtualServicePluginExtensionFiles } from './utils/writeVirtualServicePluginExtensionFiles.js';
import { writeVirtualWebhookExtensionFiles } from './utils/writeVirtualWebhookExtensionFiles.js';

const createIntegration = (): AstroIntegration => {
  let _config: AstroConfig;
  let model: Model | null = null;

  return {
    hooks: {
      async 'astro:build:done'({ logger }) {
        model ??= await createProjectModel(logger);
        const appManifest = generateAppManifest(model);

        const outDir = fileURLToPath(_config.outDir);
        const rootDir = fileURLToPath(_config.root);

        const appManifestPath = join(outDir, '_wix/app-manifest.json');

        await writeJson(appManifestPath, appManifest, { spaces: 2 });

        await writeJson(
          join(rootDir, GIT_IGNORED_DIR, 'build-metadata.json'),
          await resolveBuildMetadata(appManifestPath, _config),
          { spaces: 2 }
        );
      },
      'astro:config:done': async ({ config }) => {
        _config = config;
      },
      async 'astro:config:setup'({
        addMiddleware,
        command,
        config,
        createCodegenDir,
        injectRoute,
        injectScript,
        logger,
        updateConfig,
      }) {
        const codegenDirURL = createCodegenDir();
        const codegenDir = fileURLToPath(codegenDirURL);
        const rootDir = fileURLToPath(config.root);

        model ??= await createProjectModel(logger);

        // support client-side context calls
        injectScript(
          'before-hydration',
          outdent`
            import { WIX_CLIENT_ID } from 'astro:env/client';
            import { setup } from '@wix/astro/context/before-hydration';

            setup({ clientId: WIX_CLIENT_ID });
          `
        );

        injectScript(
          'page',
          outdent`
            import { WIX_CLIENT_ID } from 'astro:env/client';
            import { setup } from '@wix/astro/context/page';

            setup({ clientId: WIX_CLIENT_ID });
          `
        );

        // support server side context calls
        addMiddleware({
          entrypoint: new URL(
            '../build-runtime/middleware/auth.js',
            import.meta.url
          ),
          order: 'pre',
        });

        updateConfig({
          env: {
            schema: {
              WIX_CLIENT_ID: envField.string({
                access: 'public',
                context: 'client',
              }),
              WIX_CLIENT_INSTANCE_ID: envField.string({
                access: 'secret',
                context: 'server',
              }),
              WIX_CLIENT_PUBLIC_KEY: envField.string({
                access: 'secret',
                context: 'server',
              }),
              WIX_CLIENT_SECRET: envField.string({
                access: 'secret',
                context: 'server',
              }),
            },
          },
          image: {
            domains: ['static.wixstatic.com'],
            service: passthroughImageService(),
          },
          vite: {
            plugins: [patchGlobal(), patchAstroInlineScripts()],
          },
        });

        // add support for webhook extensions
        const webhookCodegenDir = join(codegenDir, 'extensions/webhooks');
        await outputDir(webhookCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL(
              '../build-runtime/routes/webhooks.js',
              import.meta.url
            ),
            pattern: `/_wix/extensions/webhooks/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualWebhookExtensionFiles(model, webhookCodegenDir);
            });
        } else {
          const webhookComponents = model.components.filter(
            isValidWebhookComponent
          );
          for (const component of webhookComponents) {
            const virtualEntrypoint = join(
              webhookCodegenDir,
              `${component.manifest.compId}.ts`
            );

            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/webhooks/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualWebhookExtensionFiles(model, webhookCodegenDir);

        // add support for service plugin extensions
        const servicePluginCodegenDir = join(
          codegenDir,
          'extensions/service-plugins'
        );
        await outputDir(servicePluginCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL(
              '../build-runtime/routes/service-plugins.js',
              import.meta.url
            ),
            pattern: `/_wix/extensions/service-plugins/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualServicePluginExtensionFiles(
                model,
                servicePluginCodegenDir
              );
            });
        } else {
          const servicePluginComponents = model.components.filter(
            isValidServicePluginComponent
          );
          for (const component of servicePluginComponents) {
            const virtualEntrypoint = join(
              servicePluginCodegenDir,
              `${component.manifest.compId}.ts`
            );
            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/service-plugins/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualServicePluginExtensionFiles(
          model,
          servicePluginCodegenDir
        );

        // add support for backoffice extensions
        const backofficeCodegenDir = join(codegenDir, 'extensions/backoffice');
        await outputDir(backofficeCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL('../runtime/entry.astro', import.meta.url),
            pattern: `/_wix/extensions/backoffice/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualBackofficeExtensionFiles(
                model,
                backofficeCodegenDir
              );
            });
        } else {
          const backofficeComponents = model.components.filter(
            isValidBackofficeComponent
          );

          for (const component of backofficeComponents) {
            const virtualEntrypoint = join(
              backofficeCodegenDir,
              `${component.manifest.compId}.astro`
            );

            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/backoffice/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualBackofficeExtensionFiles(model, backofficeCodegenDir);
      },
      'astro:server:setup': async ({ logger, server }) => {
        server.middlewares.use(async (req, res, next) => {
          if (req.url === '/_wix/app-manifest.json') {
            const model = await createProjectModel(logger);
            const appManifest = generateAppManifest(model);
            res.setHeader('Content-Type', 'application/json');
            res.end(JSON.stringify(appManifest));
            return;
          }

          next();
        });
      },
    },
    name: '@wix/astro',
  };
};

export default createIntegration;

==> astro-1.0.17.tgz: package/src/index.ts <==
import { join } from 'node:path';
import { fileURLToPath } from 'node:url';
import type { AstroConfig, AstroIntegration } from 'astro';
import { envField, passthroughImageService } from 'astro/config';
import chokidar from 'chokidar';
import { outdent } from 'outdent';
import type { Model } from './types.js';
import { EXTENSIONS_DIR, GIT_IGNORED_DIR } from './directories.js';
import { patchAstroInlineScripts } from './plugins/patchAstroInlineScripts.js';
import { patchGlobal } from './plugins/patchGlobal.js';
import { setupSsrContext } from './plugins/setupSsrContext.js';
import { createProjectModel } from './utils/createProjectModel.js';
import { outputDir, writeJson } from './utils/fs-utils.js';
import { generateAppManifest } from './utils/generateAppManifest.js';
import { isValidBackofficeComponent } from './utils/isValidBackofficeComponent.js';
import { isValidServicePluginComponent } from './utils/isValidServicePluginComponent.js';
import { isValidWebhookComponent } from './utils/isValidWebhookComponent.js';
import { resolveBuildMetadata } from './utils/resolveBuildMetadata.js';
import { writeVirtualBackofficeExtensionFiles } from './utils/writeVirtualBackofficeExtensionFiles.js';
import { writeVirtualServicePluginExtensionFiles } from './utils/writeVirtualServicePluginExtensionFiles.js';
import { writeVirtualWebhookExtensionFiles } from './utils/writeVirtualWebhookExtensionFiles.js';

const createIntegration = (): AstroIntegration => {
  let _config: AstroConfig;
  let model: Model | null = null;

  return {
    hooks: {
      async 'astro:build:done'({ logger }) {
        model ??= await createProjectModel(logger);
        const appManifest = generateAppManifest(model);

        const outDir = fileURLToPath(_config.outDir);
        const rootDir = fileURLToPath(_config.root);

        const appManifestPath = join(outDir, '_wix/app-manifest.json');

        await writeJson(appManifestPath, appManifest, { spaces: 2 });

        await writeJson(
          join(rootDir, GIT_IGNORED_DIR, 'build-metadata.json'),
          await resolveBuildMetadata(appManifestPath, _config),
          { spaces: 2 }
        );
      },
      'astro:config:done': async ({ config }) => {
        _config = config;
      },
      async 'astro:config:setup'({
        addMiddleware,
        command,
        config,
        createCodegenDir,
        injectRoute,
        injectScript,
        logger,
        updateConfig,
      }) {
        const codegenDirURL = createCodegenDir();
        const codegenDir = fileURLToPath(codegenDirURL);
        const rootDir = fileURLToPath(config.root);

        model ??= await createProjectModel(logger);

        // support client-side context calls
        injectScript(
          'before-hydration',
          outdent`
            import { WIX_CLIENT_ID } from 'astro:env/client';
            import { setup } from '@wix/astro/context/setup';

            setup({ clientId: WIX_CLIENT_ID });
          `
        );

        injectScript(
          'page',
          outdent`
            import { WIX_CLIENT_ID } from 'astro:env/client';
            import { setup } from '@wix/astro/context/setup';

            setup({ clientId: WIX_CLIENT_ID });
          `
        );

        // support server side context calls
        addMiddleware({
          entrypoint: new URL(
            '../build-runtime/middleware/auth.js',
            import.meta.url
          ),
          order: 'pre',
        });

        updateConfig({
          env: {
            schema: {
              WIX_CLIENT_ID: envField.string({
                access: 'public',
                context: 'client',
              }),
              WIX_CLIENT_INSTANCE_ID: envField.string({
                access: 'secret',
                context: 'server',
              }),
              WIX_CLIENT_PUBLIC_KEY: envField.string({
                access: 'secret',
                context: 'server',
              }),
              WIX_CLIENT_SECRET: envField.string({
                access: 'secret',
                context: 'server',
              }),
            },
          },
          image: {
            domains: ['static.wixstatic.com'],
            service: passthroughImageService(),
          },
          vite: {
            plugins: [
              patchGlobal(),
              patchAstroInlineScripts(),
              setupSsrContext(rootDir),
            ],
          },
        });

        // add support for webhook extensions
        const webhookCodegenDir = join(codegenDir, 'extensions/webhooks');
        await outputDir(webhookCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL(
              '../build-runtime/routes/webhooks.js',
              import.meta.url
            ),
            pattern: `/_wix/extensions/webhooks/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualWebhookExtensionFiles(model, webhookCodegenDir);
            });
        } else {
          const webhookComponents = model.components.filter(
            isValidWebhookComponent
          );
          for (const component of webhookComponents) {
            const virtualEntrypoint = join(
              webhookCodegenDir,
              `${component.manifest.compId}.ts`
            );

            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/webhooks/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualWebhookExtensionFiles(model, webhookCodegenDir);

        // add support for service plugin extensions
        const servicePluginCodegenDir = join(
          codegenDir,
          'extensions/service-plugins'
        );
        await outputDir(servicePluginCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL(
              '../build-runtime/routes/service-plugins.js',
              import.meta.url
            ),
            pattern: `/_wix/extensions/service-plugins/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualServicePluginExtensionFiles(
                model,
                servicePluginCodegenDir
              );
            });
        } else {
          const servicePluginComponents = model.components.filter(
            isValidServicePluginComponent
          );
          for (const component of servicePluginComponents) {
            const virtualEntrypoint = join(
              servicePluginCodegenDir,
              `${component.manifest.compId}.ts`
            );
            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/service-plugins/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualServicePluginExtensionFiles(
          model,
          servicePluginCodegenDir
        );

        // add support for backoffice extensions
        const backofficeCodegenDir = join(codegenDir, 'extensions/backoffice');
        await outputDir(backofficeCodegenDir);

        if (command === 'dev') {
          injectRoute({
            entrypoint: new URL('../runtime/entry.astro', import.meta.url),
            pattern: `/_wix/extensions/backoffice/[compId]`,
            prerender: false,
          });

          chokidar
            .watch([EXTENSIONS_DIR], {
              cwd: rootDir,
              ignoreInitial: true,
              useFsEvents: false,
            })
            .on('all', async () => {
              model = await createProjectModel(logger);
              await writeVirtualBackofficeExtensionFiles(
                model,
                backofficeCodegenDir
              );
            });
        } else {
          const backofficeComponents = model.components.filter(
            isValidBackofficeComponent
          );

          for (const component of backofficeComponents) {
            const virtualEntrypoint = join(
              backofficeCodegenDir,
              `${component.manifest.compId}.astro`
            );

            injectRoute({
              entrypoint: virtualEntrypoint,
              pattern: `/_wix/extensions/backoffice/${component.manifest.compId}`,
            });
          }
        }

        await writeVirtualBackofficeExtensionFiles(model, backofficeCodegenDir);
      },
      'astro:server:setup': async ({ logger, server }) => {
        server.middlewares.use(async (req, res, next) => {
          if (req.url === '/_wix/app-manifest.json') {
            const model = await createProjectModel(logger);
            const appManifest = generateAppManifest(model);
            res.setHeader('Content-Type', 'application/json');
            res.end(JSON.stringify(appManifest));
            return;
          }

          next();
        });
      },
    },
    name: '@wix/astro',
  };
};

export default createIntegration;
